==> julia-git-mathoptinterface-src-1.36.0-1-any.pkg.tar.zst: usr/share/julia/arch-site/MathOptInterface/README.md <==
# MathOptInterface

| **Documentation** | **Build Status** |
|:-----------------:|:----------------:|
| [![][docs-stable-img]][docs-stable-url] [![][docs-dev-img]][docs-dev-url] | [![Build Status][build-img]][build-url] [![Codecov branch][codecov-img]][codecov-url] |

An abstraction layer for mathematical optimization solvers. Replaces [MathProgBase](https://github.com/JuliaOpt/MathProgBase.jl).

[docs-stable-img]: https://img.shields.io/badge/docs-stable-blue.svg
[docs-dev-img]: https://img.shields.io/badge/docs-dev-blue.svg
[docs-stable-url]: http://jump.dev/MathOptInterface.jl/stable
[docs-dev-url]: http://jump.dev/MathOptInterface.jl/dev

[build-img]: https://github.com/JuMP-dev/MathOptInterface.jl/actions/workflows/ci.yml/badge.svg?branch=master
[build-url]: https://github.com/JuMP-dev/MathOptInterface.jl/actions?query=workflow%3ACI
[codecov-img]: http://codecov.io/github/JuMP-dev/MathOptInterface.jl/coverage.svg?branch=master
[codecov-url]: http://codecov.io/github/JuMP-dev/MathOptInterface.jl?branch=master

## Citing MathOptInterface

If you find MathOptInterface useful in your work, we kindly request that you cite the
following [paper](https://pubsonline.informs.org/doi/10.1287/ijoc.2021.1067):
```bibtex
@article{legat2021mathoptinterface,
    title={{MathOptInterface}: a data structure for mathematical optimization problems},
    author={Legat, Beno{\^\i}t and Dowson, Oscar and Dias Garcia, Joaquim and Lubin, Miles},
    journal={INFORMS Journal on Computing},
    year={2021},
    volume={34},
    number={2},
    pages={672--689},
    doi={10.1287/ijoc.2021.1067},
    publisher={INFORMS}
}
```
A preprint of this paper is [freely available](https://arxiv.org/abs/2002.03447).

==> julia-git-mathoptinterface-src-1.37.0-1-any.pkg.tar.zst: usr/share/julia/arch-site/MathOptInterface/README.md <==
# MathOptInterface

| **Documentation** | **Build Status** |
|:-----------------:|:----------------:|
| [![][docs-stable-img]][docs-stable-url] [![][docs-dev-img]][docs-dev-url] | [![Build Status][build-img]][build-url] [![Codecov branch][codecov-img]][codecov-url] |

An abstraction layer for mathematical optimization solvers.

[docs-stable-img]: https://img.shields.io/badge/docs-stable-blue.svg
[docs-dev-img]: https://img.shields.io/badge/docs-dev-blue.svg
[docs-stable-url]: http://jump.dev/MathOptInterface.jl/stable
[docs-dev-url]: http://jump.dev/MathOptInterface.jl/dev

[build-img]: https://github.com/JuMP-dev/MathOptInterface.jl/actions/workflows/ci.yml/badge.svg?branch=master
[build-url]: https://github.com/JuMP-dev/MathOptInterface.jl/actions?query=workflow%3ACI
[codecov-img]: https://codecov.io/gh/JuMP-dev/MathOptInterface.jl/branch/master/graph/badge.svg
[codecov-url]: https://codecov.io/gh/JuMP-dev/MathOptInterface.jl/branch/master

## Citing MathOptInterface

If you find MathOptInterface useful in your work, we kindly request that you cite the
following [paper](https://pubsonline.informs.org/doi/10.1287/ijoc.2021.1067):
```bibtex
@article{legat2021mathoptinterface,
    title={{MathOptInterface}: a data structure for mathematical optimization problems},
    author={Legat, Beno{\^\i}t and Dowson, Oscar and Dias Garcia, Joaquim and Lubin, Miles},
    journal={INFORMS Journal on Computing},
    year={2021},
    volume={34},
    number={2},
    pages={672--689},
    doi={10.1287/ijoc.2021.1067},
    publisher={INFORMS}
}
```
A preprint of this paper is [freely available](https://arxiv.org/abs/2002.03447).
